==> 4.0.0-ISS-GKLM-FP0005-AIX.tar.gz: _uninst/removeDB2Inst.sh <==
#!/usr/bin/env bash
#set -x
############################################################################################### 
# Licensed Materials - Property of IBM
#
# 5724-T60 5608-A91
# (C) Copyright IBM Corp. 2008, 2009  All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplication, or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###############################################################################################
# Verify input
#TODO:need detailed usage statement

printusage() {
echo "usage: removeDb2Inst DB2_INST_HOME DB2_SERV_NAME DB2_HOME DB2_INST  DB_NAME
  where
  DB2_INST_HOME is the home directory of the database instance owner
  DB2_SERV_NAME Db2 service name
  DB2_HOME is the directory where DB2 is installed
  DB2_INST is the Database Instance Owner specified during the install
  DB2_NAME is the name of the database"
  exit 1
}

stopDB2() {
	echo Stopping DB2 service...
	if [ "$UNAME" =  "AIX" ]; then
   		db2stop force >> /${TKLMTEMP}/removeDB2Inst.output.txt
   	else
   		sudo service $SERVICENAME stop >> /${TKLMTEMP}/removeDB2Inst.output.txtbash
	fi
}

startDB2() {
	echo Starting DB2 service...
	if [ "$UNAME" =  "AIX" ]; then
   		db2start >> /${TKLMTEMP}/removeDB2Inst.output.txt
   	else
   		sudo service $SERVICENAME start >> /${TKLMTEMP}/removeDB2Inst.output.txt
	fi
}

#=======MAIN============
SCRIPTHOME=${PWD}
TKLMTEMP=${HOME}/sklm40properties
UNAME=`uname`

if [ $# -le 0 ]; then
	echo count=0
    if [[ -f ${SCRIPTHOME}/db2unix.srcit ]]; then
           . ${SCRIPTHOME}/"db2unix.srcit"
	else
		echo "The DB2 variables cannot be determined. The ${SCRIPTHOME}/db2unix.srcit is missing. Run script again by specifying DB2 parameters."
	   	printusage
	   	exit 1 
    fi
elif [ $# -eq 2 ]; then
	echo count=2
	export INSTANCEHOME="$1"
	export SERVICENAME="$2"
	echo INSTANCEHOME=${INSTANCEHOME}
	echo SERVICENAME=${SERVICENAME}
	echo UNAME=${UNAME}
	TKLMTEMP=${INSTANCEHOME}/sklm40properties
    if [[ -f ${TKLMTEMP}/db2unix.srcit ]]; then
    	echo file ${TKLMTEMP}/db2unix.srcit found
    	. ${TKLMTEMP}/"db2unix.srcit"
    elif [[ -f ${TKLMTEMP}/scripts/db2unix.srcit ]]; then
    	echo file ${TKLMTEMP}/db2unix.srcit found
    	. ${TKLMTEMP}/scripts/db2unix.srcit
    else
    	echo "The DB2 variables cannot be determined. The ${TKLMTEMP}/db2unix.srcit is missing. Run script again by specifying DB2 parameters."
	   	printusage
	   	exit 1 
	fi
else
	echo count=5
   export INSTANCEHOME="$1"
   export SERVICENAME="$2"
   export DB2INSTALLDIR="$3"
   export DB2ADMIN="$4"
   export DB2DBNAME="$5"
fi

#echo "DB2 HOME "  $DB2INSTALLDIR 
#echo "DB2 INSTANCE NAME " $DB2ADMIN
#echo "DB2 INSTANCE HOME " $INSTANCEHOME
#echo "DB2 DATABASE NAME " $DB2DBNAME

GID=`id -g`

if [ "$DB2INSTALLDIR" =  "" ]; then
   printusage
fi
if [ "$SERVICENAME" =  "" ]; then
   printusage
fi
if [ "$DB2ADMIN" =  "" ]; then
   printusage
fi

if [ "$INSTANCEHOME" =  "" ]; then
   printusage
fi

if [ "$DB2DBNAME" =  "" ]; then
   printusage
fi

#Warn the user about losing data
#ask=0
#while ((ask>0))
#do
#echo  "\nYou will lose the database instance and all data in it when you run this shell script, are you sure you want to continue?(yes/no) "
#read response 
#if [ "$response" = "no" ]; then 
#echo 
#echo "Uninstall is cancelled."
#echo
#exit 1
#fi
#if [ "$response" = "yes" ]; then 
#	ask=0
#else
#   echo 
#   echo "You specified ${response}. Enter yes to continue with the uninstallation and no to cancel uninstallation"
#   echo
#fi
#done

#echo "Removing database instance..."
#echo "DB2 Instance uninstall started" > /${TKLMTEMP}/removeDB2Inst.output.txt

if [ -d "${DB2INSTALLDIR}" ]; then
  . ${INSTANCEHOME}/sqllib/db2profile
  stopDB2
  startDB2
  
	if [ $GID -eq 0  ]; then
		su - $DB2ADMIN  -c "db2 drop database $DB2DBNAME" >> /${TKLMTEMP}/removeDB2Inst.output.txt
	else
		db2 drop database $DB2DBNAME >> /${TKLMTEMP}/removeDB2Inst.output.txt
	fi
  
  echo stopping database service ...>> /${TKLMTEMP}/removeDB2Inst.output.txt  
  stopDB2

  echo Dropping database instance...>> /${TKLMTEMP}/removeDB2Inst.output.txt 
  	if [ $GID -eq 0  ]; then
		#su - $DB2ADMIN  -c "$DB2INSTALLDIR/instance/db2idrop  $DB2ADMIN" >> /${TKLMTEMP}/removeDB2Inst.output.txt
		$DB2INSTALLDIR/instance/db2idrop  $DB2ADMIN >> /${TKLMTEMP}/removeDB2Inst.output.txt
	else
		$DB2INSTALLDIR/instance/db2idrop  $DB2ADMIN >> /${TKLMTEMP}/removeDB2Inst.output.txt
	fi
  
  RC=$?
else
  echo "Error:" $DB2INSTALLDIR " does not exist" >> /${TKLMTEMP}/removeDB2Inst.output.txt
  RC=-10
fi

if [ $RC -eq 0 ]; then
	if [ -d "$INSTANCEHOME/sqllib" ]; then
		rm -rf $INSTANCEHOME/sqllib >> /${TKLMTEMP}/removeDB2Inst.output.txt
	fi
  	if [ -d "$INSTANCEHOME/sqllib_v91" ]; then
		rm -rf $INSTANCEHOME/sqllib_v91 >> /${TKLMTEMP}/removeDB2Inst.output.txt
	fi
  	if [ -d "$INSTANCEHOME/$DB2ADMIN" ]; then
		rm -rf  $INSTANCEHOME/$DB2ADMIN >> /${TKLMTEMP}/removeDB2Inst.output.txt
	fi
  	if [ -d "$INSTANCEHOME/sklmdbarchive" ]; then
		rm -rf $INSTANCEHOME/sklmdbarchive >> /${TKLMTEMP}/removeDB2Inst.output.txt
	fi
	
	#Cleanup /etc/services entry for db2
   	if [ `cat /etc/services | grep "${SERVICENAME}" | wc -l` -ge 1  ] ; then
      echo -n "INFO : Removing sklm db service entry from '/etc/services'..."
      sed "/${SERVICENAME}/,/^/d" /etc/services > /tmp/.services && mv -f /tmp/.services /etc/services
      if [ $? == 0 ] ; then echo "done."; else echo "failed."; exitVal=2; fi
   	fi 
  	RC=$?
fi

if [ -d "/var/db2" ]; then
	rm -rf /var/db2 >> /${TKLMTEMP}/removeDB2Inst.output.txt
fi	
userdel -r klmfcusr >> /${TKLMTEMP}/removeDB2Inst.output.txt
#userdel -r ${DB2ADMIN} >> /${TKLMTEMP}/removeDB2Inst.output.txt
#if [ RC -eq 0 ]; then
#  echo "Uninstall DB2 instance is complete. You can look at /${TKLMTEMP}/removeDB2Inst.output.txt for more information"
#else
#  echo "Uninstall DB2 instance failed. You can look at /${TKLMTEMP}/removeDB2Inst.output.txt for more information"
#  echo "exiting with " $RC
#fi
#exit $RC

==> 4.1.0-ISS-GKLM-FP0005-AIX.tar.gz: _uninst/removeDB2Inst.sh <==
#!/usr/bin/env bash
#set -x
############################################################################################### 
# Licensed Materials - Property of IBM
#
# 5724-T60 5608-A91
# (C) Copyright IBM Corp. 2008, 2009  All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplication, or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###############################################################################################
# Verify input
#TODO:need detailed usage statement

printusage() {
echo "usage: removeDb2Inst DB2_INST_HOME DB2_SERV_NAME DB2_HOME DB2_INST  DB_NAME
  where
  DB2_INST_HOME is the home directory of the database instance owner
  DB2_SERV_NAME Db2 service name
  DB2_HOME is the directory where DB2 is installed
  DB2_INST is the Database Instance Owner specified during the install
  DB2_NAME is the name of the database"
  exit 1
}

stopDB2() {
	echo Stopping DB2 service...
	if [ "$UNAME" =  "AIX" ]; then
   		db2stop force >> /${TKLMTEMP}/removeDB2Inst.output.txt
   	else
   		sudo service $SERVICENAME stop >> /${TKLMTEMP}/removeDB2Inst.output.txtbash
	fi
}

startDB2() {
	echo Starting DB2 service...
	if [ "$UNAME" =  "AIX" ]; then
   		db2start >> /${TKLMTEMP}/removeDB2Inst.output.txt
   	else
   		sudo service $SERVICENAME start >> /${TKLMTEMP}/removeDB2Inst.output.txt
	fi
}

#=======MAIN============
SCRIPTHOME=${PWD}
TKLMTEMP=${HOME}/sklm41properties
UNAME=`uname`

if [ $# -le 0 ]; then
	echo count=0
    if [[ -f ${SCRIPTHOME}/db2unix.srcit ]]; then
           . ${SCRIPTHOME}/"db2unix.srcit"
	else
		echo "The DB2 variables cannot be determined. The ${SCRIPTHOME}/db2unix.srcit is missing. Run script again by specifying DB2 parameters."
	   	printusage
	   	exit 1 
    fi
elif [ $# -eq 2 ]; then
	echo count=2
	export INSTANCEHOME="$1"
	export SERVICENAME="$2"
	echo INSTANCEHOME=${INSTANCEHOME}
	echo SERVICENAME=${SERVICENAME}
	echo UNAME=${UNAME}
	TKLMTEMP=${INSTANCEHOME}/sklm41properties
    if [[ -f ${TKLMTEMP}/db2unix.srcit ]]; then
    	echo file ${TKLMTEMP}/db2unix.srcit found
    	. ${TKLMTEMP}/"db2unix.srcit"
    elif [[ -f ${TKLMTEMP}/scripts/db2unix.srcit ]]; then
    	echo file ${TKLMTEMP}/db2unix.srcit found
    	. ${TKLMTEMP}/scripts/db2unix.srcit
    else
    	echo "The DB2 variables cannot be determined. The ${TKLMTEMP}/db2unix.srcit is missing. Run script again by specifying DB2 parameters."
	   	printusage
	   	exit 1 
	fi
else
	echo count=5
   export INSTANCEHOME="$1"
   export SERVICENAME="$2"
   export DB2INSTALLDIR="$3"
   export DB2ADMIN="$4"
   export DB2DBNAME="$5"
fi

#echo "DB2 HOME "  $DB2INSTALLDIR 
#echo "DB2 INSTANCE NAME " $DB2ADMIN
#echo "DB2 INSTANCE HOME " $INSTANCEHOME
#echo "DB2 DATABASE NAME " $DB2DBNAME

GID=`id -g`

if [ "$DB2INSTALLDIR" =  "" ]; then
   printusage
fi
if [ "$SERVICENAME" =  "" ]; then
   printusage
fi
if [ "$DB2ADMIN" =  "" ]; then
   printusage
fi

if [ "$INSTANCEHOME" =  "" ]; then
   printusage
fi

if [ "$DB2DBNAME" =  "" ]; then
   printusage
fi

#Warn the user about losing data
#ask=0
#while ((ask>0))
#do
#echo  "\nYou will lose the database instance and all data in it when you run this shell script, are you sure you want to continue?(yes/no) "
#read response 
#if [ "$response" = "no" ]; then 
#echo 
#echo "Uninstall is cancelled."
#echo
#exit 1
#fi
#if [ "$response" = "yes" ]; then 
#	ask=0
#else
#   echo 
#   echo "You specified ${response}. Enter yes to continue with the uninstallation and no to cancel uninstallation"
#   echo
#fi
#done

#echo "Removing database instance..."
#echo "DB2 Instance uninstall started" > /${TKLMTEMP}/removeDB2Inst.output.txt

if [ -d "${DB2INSTALLDIR}" ]; then
  . ${INSTANCEHOME}/sqllib/db2profile
  stopDB2
  startDB2
  
  echo executing db2 force applications all query to disconnect all applications from the database server ..>> /${TKLMTEMP}/removeDB2Inst.output.txt 
  sudo -i -u ${DB2ADMIN} db2 force applications all >> /${TKLMTEMP}/removeDB2Inst.output.txt 
  
	if [ $GID -eq 0  ]; then
		su - $DB2ADMIN  -c "db2 drop database $DB2DBNAME" >> /${TKLMTEMP}/removeDB2Inst.output.txt
	else
		db2 drop database $DB2DBNAME >> /${TKLMTEMP}/removeDB2Inst.output.txt
	fi
  
  echo "listing active db2 instances using db2ilist ..." >> /${TKLMTEMP}/removeDB2Inst.output.txt 
  ${DB2INSTALLDIR}/instance/db2ilist >> /${TKLMTEMP}/removeDB2Inst.output.txt
  
  echo "switching to ${DB2ADMIN} and stopping database manager using db2stop force in ${DB2INSTALLDIR} directory" >> /${TKLMTEMP}/removeDB2Inst.output.txt 
  sudo -i -u ${DB2ADMIN} ${DB2INSTALLDIR}/adm/db2stop force >>  /${TKLMTEMP}/removeDB2Inst.output.txt 
  
  echo terminating the database ... >> /${TKLMTEMP}/removeDB2Inst.output.txt 
  su - $DB2ADMIN  -c "db2 terminate" >> /${TKLMTEMP}/removeDB2Inst.output.txt 
  
  echo stopping database service ...>> /${TKLMTEMP}/removeDB2Inst.output.txt  
  stopDB2
  
  echo "executing ipclean command to remove the DB2 engine and clients IPC resources for instance...." >> /${TKLMTEMP}/removeDB2Inst.output.txt 
  sudo -i -u ${DB2ADMIN} ${DB2INSTALLDIR}/bin/ipclean -a >> /${TKLMTEMP}/removeDB2Inst.output.txt 

  echo Dropping database instance...>> /${TKLMTEMP}/removeDB2Inst.output.txt 
  	if [ $GID -eq 0  ]; then
  	    echo "changing ownership of db2 instance home and installation directory back to the owner of installation copy aka root..." >> /${TKLMTEMP}/removeDB2Inst.output.txt 
  	    chown -R root:root ${INSTANCEHOME}
  	    chown -R root:root ${DB2INSTALLDIR}
		$DB2INSTALLDIR/instance/db2idrop  $DB2ADMIN >> /${TKLMTEMP}/removeDB2Inst.output.txt
	    echo "changing back ownership of db2 instance home to instance owner" >> ${logfile}
	    chown -R ${DB2ADMIN}:${DB2ADMIN} ${INSTANCEHOME}
	else
		$DB2INSTALLDIR/instance/db2idrop  $DB2ADMIN >> /${TKLMTEMP}/removeDB2Inst.output.txt
	fi
  
  RC=$?
else
  echo "Error:" $DB2INSTALLDIR " does not exist" >> /${TKLMTEMP}/removeDB2Inst.output.txt
  RC=-10
fi

if [ $RC -eq 0 ]; then
	if [ -d "$INSTANCEHOME/sqllib" ]; then
		rm -rf $INSTANCEHOME/sqllib >> /${TKLMTEMP}/removeDB2Inst.output.txt
	fi
  	if [ -d "$INSTANCEHOME/sqllib_v91" ]; then
		rm -rf $INSTANCEHOME/sqllib_v91 >> /${TKLMTEMP}/removeDB2Inst.output.txt
	fi
  	if [ -d "$INSTANCEHOME/$DB2ADMIN" ]; then
		rm -rf  $INSTANCEHOME/$DB2ADMIN >> /${TKLMTEMP}/removeDB2Inst.output.txt
	fi
  	if [ -d "$INSTANCEHOME/sklmdbarchive" ]; then
		rm -rf $INSTANCEHOME/sklmdbarchive >> /${TKLMTEMP}/removeDB2Inst.output.txt
	fi
	
	#Cleanup /etc/services entry for db2
   	if [ `cat /etc/services | grep "${SERVICENAME}" | wc -l` -ge 1  ] ; then
      echo -n "INFO : Removing sklm db service entry from '/etc/services'..."
      sed "/${SERVICENAME}/,/^/d" /etc/services > /tmp/.services && mv -f /tmp/.services /etc/services
      if [ $? == 0 ] ; then echo "done."; else echo "failed."; exitVal=2; fi
   	fi 
  	RC=$?
fi

if [ -d "/var/db2" ]; then
	rm -rf /var/db2 >> /${TKLMTEMP}/removeDB2Inst.output.txt
fi	
#userdel -r klmfcusr >> /${TKLMTEMP}/removeDB2Inst.output.txt
#userdel -r ${DB2ADMIN} >> /${TKLMTEMP}/removeDB2Inst.output.txt
#if [ RC -eq 0 ]; then
#  echo "Uninstall DB2 instance is complete. You can look at /${TKLMTEMP}/removeDB2Inst.output.txt for more information"
#else
#  echo "Uninstall DB2 instance failed. You can look at /${TKLMTEMP}/removeDB2Inst.output.txt for more information"
#  echo "exiting with " $RC
#fi
#exit $RC
